netapp_ontap.models.fc_login_initiator API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fc_login_initiator`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FcLoginInitiatorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcLoginInitiator object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `aliases GET`

    The logged in initiator world wide port name (WWPN) aliases.

  `port_address GET`

    The port address of the initiator's FC port.
    Each port in an FC switched fabric has its own unique port address for routing purposes. The port address is assigned by a switch in the fabric when that port logs in to the fabric. This property refers to the address given by a switch to the initiator port.
    This is useful for obtaining statistics and diagnostic information from FC switches.
    This is a hexadecimal encoded numeric value.

    Example: 5060A

  `wwnn GET`

    The logged in initiator world wide node name (WWNN).

    Example: 2f:a0:00:a0:98:0b:56:13

  `wwpn GET`

    The logged in initiator WWPN.

    Example: 2f:a0:00:a0:98:0b:56:13